#
# spec file for package python-furl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define skip_python2 1
Name:           python-furl
Version:        2.1.3
Release:        5.3
Summary:        A Python URL manipulation library
License:        Unlicense
Group:          Development/Languages/Python
URL:            https://github.com/gruns/furl
Source:         https://files.pythonhosted.org/packages/source/f/furl/furl-%{version}.tar.gz
# PATCH-FIX-UPSTREAM 165-use-ipaddress-library.patch gh#gruns/furl#164 mcepl@suse.com
# use ipaddress to parse IP addresses
Patch0:         165-use-ipaddress-library.patch
Patch1:         netloc-tests.patch
# PATCH-FEATURE-UPSTREAM remove-six.patch gh#gruns/furl#175 mcepl@suse.com
# remove the need of using six
Patch2:         remove-six.patch
# PATCH-FIX-UPSTREAM fix-test_odd_urls.patch gh#gruns/furl#176 mcepl@suse.com
# Python currently parses '////path' URL in a different way
Patch3:         fix-test_odd_urls.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-orderedmultidict >= 1.0.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module orderedmultidict >= 1.0.1}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
furl is a Python library for parsing and manipulating URLs.

%prep
%autosetup -p1 -n furl-%{version}
chmod -x *.md furl.egg-info/*

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/furl
%{python_sitelib}/furl-%{version}*-info

%changelog
* Fri Sep 13 2024 Matej Cepl <mcepl@cepl.eu>
- Add remove-six.patch (gh#gruns/furl#175) removing the
  dependency on six.
- Add fix-test_odd_urls.patch fixing the failure of
  tests/test_furl.py::TestFurl::test_odd_urls test with the
  recent Python interpreters (gh#gruns/furl#176).
* Tue Jul  2 2024 Dirk Müller <dmueller@suse.com>
- add netloc-tests.patch to skip failing test with python 3.12
* Tue Jul  4 2023 Matej Cepl <mcepl@suse.com>
- Add 165-use-ipaddress-library.patch to use standard ipaddress
  library to parse IP addresses (gh#gruns/furl#164).
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to v2.1.3
  Fixed: Actually drop ';' as a query delimiter. See furl v2.1.2's
  changelog and https://bugs.python.org/issue42967.
* Fri Aug 19 2022 Ben Greiner <code@bnavigator.de>
- Skip python2: Fixes 15.X build
- Remove flake8 test requirement: no code linting required for
  packaging
* Mon May 17 2021 pgajdos@suse.com
- version update to 2.1.2
  Fixed: Support Python 3.9's changed urllib.parse.urljoin() behavior.
  Changed: Drop semicolon query delimiters. See https://bugs.python.org/issue42967.
  Changed: Drop support for EOL Python 3.4 and Python 3.5.
- deleted patches
  - furl-py39-join.patch (upstreamed)
  - tests_overcome_bpo42967.patch (upstreamed)
* Mon Mar 29 2021 Ben Greiner <code@bnavigator.de>
- Add furl-py39-join.patch to fix Python 3.9 test failure
  gh#gruns/furl#139
- Submitted tests_overcome_bpo42967.patch as gh#gruns/furl#140
* Tue Feb 23 2021 Matej Cepl <mcepl@suse.com>
- Switch testing to pytest, it is just more convenient to debug.
- Add tests_overcome_bpo42967.patch to overcome changes in Python
  interpreter after fixing bpo#42967 (gh#gruns/furl#135).
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 2.1.0
    Added: a dont_quote= parameter to Query.encode() and a
    query_dont_quote= parameter to furl.tostr() that exempt valid query
    characters from being percent-encoded, either in their entirety with
    dont_quote=True, or selectively with dont_quote=<string>, like
    dont_quote='/?@_'.
    Changed: Move package info from __init__.py into the more standard
    __version__.py.
    Fixed: Support Unicode usernames and passwords in Python 2.
    Fixed: Update orderedmultdict to v1.0.1 to resolve a DeprecationWarning.
    Fixed: Encode '/' consistently in query strings across both
    quote_plus=True and quote_plus=False.
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Sun Jun  2 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.0.0
